@@ -128,17 +128,19 @@ function display(x)
   end
   s = [s1 s2];
   n = ustr_length (s);
+  %fputs (1, s);  % only in octave, not matlab
   fprintf (s)
   if (display_snippet)
+    % again, fputs safer, but not in matlab
     fprintf (snippet_of_sympy (x, 7, term_width - n, unicode_dec))
   end
   fprintf ('\n');
 
   if (toobig)
     if (loose), fprintf ('\n'); end
-    fprintf (dispstr)
+    % don't use printf b/c ascii-art might have slashes
+    disp (dispstr);  % appends newline
     if (loose), fprintf ('\n'); end
-    fprintf ('\n');
   end
 end
 
